@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -24,7 +24,6 @@
 #include <QFileDialog>
 #include <QHBoxLayout>
 #include <QPointer>
-#include <kwidgetsaddons_version.h>
 
 ContactEditorPage::ContactEditorPage(const QString &projectDir, const QString &themeName, QWidget *parent)
     : QWidget(parent)
@@ -120,20 +119,12 @@ void ContactEditorPage::installTheme(const QString &themePath)
     QDir dir(themePath);
     QDir themeDir(themePath + QLatin1Char('/') + mDesktopPage->themeName());
     if (themeDir.exists()) {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         const int answer = KMessageBox::questionTwoActions(this,
-#else
-        const int answer = KMessageBox::questionYesNo(this,
-#endif
                                                            i18n("Theme already exists. Do you want to overwrite it?"),
                                                            i18n("Theme already exists"),
                                                            KStandardGuiItem::overwrite(),
                                                            KStandardGuiItem::cancel());
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         if (answer == KMessageBox::ButtonCode::SecondaryAction) {
-#else
-        if (answer == KMessageBox::No) {
-#endif
             return;
         }
     } else {
@@ -277,20 +268,12 @@ bool ContactEditorPage::saveTheme(bool withConfirmation)
 {
     if (themeWasChanged()) {
         if (withConfirmation) {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
             const int result = KMessageBox::questionTwoActionsCancel(this,
-#else
-            const int result = KMessageBox::questionYesNoCancel(this,
-#endif
                                                                      i18n("Do you want to save current project?"),
                                                                      i18n("Save current project"),
                                                                      KStandardGuiItem::save(),
                                                                      KStandardGuiItem::discard());
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
             if (result == KMessageBox::ButtonCode::PrimaryAction) {
-#else
-            if (result == KMessageBox::Yes) {
-#endif
                 storeTheme();
             } else if (result == KMessageBox::Cancel) {
                 return false;
